@@ -3,10 +3,10 @@
 #define PID_FILE "/var/run/hwscand.pid"
 
 // WARNING NEEDS TO BE <= 9
-#define NR_COMMANDS 5
+#define NR_COMMANDS 7
 // WARNING NEEDS TO BE <= 9
-static const char *command_args[] = { "block", "partition", "usb", "firewire", "pci" };
-static const int command_with_device[] = { 1, 1, 0, 0, 0 };
+static const char *command_args[] = { "block", "partition", "usb", "firewire", "pci", "pcmcia", "bluetooth" };
+static const int command_with_device[] = { 1, 1, 0, 0, 0, 0, 0 };
 
 typedef struct msgbuf {
         long mtype;
