@@ -50,7 +50,6 @@ void hd_scan_misc(hd_data_t *hd_data)
 
   PROGRESS(9, 0, "kernel log");
   read_klog(hd_data);
-  if((hd_data->debug & HD_DEB_MISC)) dump_klog(hd_data);
 
   PROGRESS(1, 0, "misc data");
   hd_data->misc = new_mem(sizeof *hd_data->misc);
@@ -342,26 +341,13 @@ void hd_scan_misc2(hd_data_t *hd_data)
         have_common_res(hd->res, res)
       ) break;
     }
-    if(!hd) {
-      /* eg. non-PCI IDE controller */
-      hd = add_hd_entry(hd_data, __LINE__, 0);
-      hd->base_class.id = bc_storage;
-      hd->sub_class.id = sc_sto_ide;
-      hd->compat_vendor.id = MAKE_ID(TAG_SPECIAL, 0x3000);
-      hd->compat_device.id = MAKE_ID(TAG_SPECIAL, 0x1000);
-      /* use join_res to join the i/o ranges of ide0/1 */
-      join_res_io(&hd->res, res);
-      join_res_irq(&hd->res, res);
-      join_res_dma(&hd->res, res);
-      free_res_list(res);
-    }
-    else {
+    if(hd) {
       /* eg. PCI IDE controller, add resources */
       join_res_io(&hd->res, res);
       join_res_irq(&hd->res, res);
       join_res_dma(&hd->res, res);
-      free_res_list(res);
     }
+    free_res_list(res);
   }
 
   /* VGA */
